#!/bin/bash

######################################################################################################################################################################################################################################################################################
# To take .com files used for Gaussian SP crystal calculations in DMACRYS to gas phase opt freq calculations in a new directory. The Script includes some basic error checking but is not completely reliable please check raw output.                                               #
# Please edit the fixed variable GAS as suggested                                                                                                                                                                                                                                    #
# Please leave the script dmacrys_output.sh in the same directory as this one and run this script in the parent directory your DMACRYS output                                                                                                                                        #
# Please edit the batch job section as suggested                                                                                                                                                                                                                                     #
# The script assumes a different directory exists for each molecule run through DMACRYS and the directories end with _CRYS                                                                                                                                                           #
# Written in the University of St Andrews in the Mitchell and van Mourik research groups by J.McD.                                                                                                                                                                                   #
######################################################################################################################################################################################################################################################################################

#Fixed Variables
#GAS= PLEASE ENTER THE DIRECTORY YOU WANT THE GAS INPUT TO BE COPIED TO AND REMOVE THE HASH MARK FROM THE BEGINNING OF THIS LINE
a=0
home=`pwd`



#Move to the Crystal directory
echo 
echo Current directory is $home
echo do you want to use the current directory to read the crystal inputs from? '(y/n)' 
read ans
if [ $ans == "n" ]
then 
  	  echo enter directory path for use eg '(/home/crystals/)'
	  read crys_1
	  cd $crys_1
	  pwd
elif [$ans == "y"]
then
 	 pwd
fi


#Make the comfiles.out file 
./dmacrys_output.sh

grep -B1 'VALID MINIMISATION' dmacrys_output.end > valid_outputs.tmp
sed -i 's/-//g' valid_outputs.tmp
sed -i '/VALID/d' valid_outputs.tmp
grep . valid_outputs.tmp > valid_outputs.out
cp valid_outputs.out comfiles.out
sed -i 's/_CRYS/'.'com/g' comfiles.out
mv dmacrys_output.end dmacrys_output.out
rm valid_outputs.tmp

# Move files to the directories
while read line
do
	a=$(($a+1))
	echo new a is $a therefore reading from line number $a
	i=`sed -n $a'p' valid_outputs.out`
	echo $i 
	cp $i/gaussian/*.com $GAS
done < valid_outputs.out
a=0

echo a is reset to $a '(a should increase by an increment of 1 each 'time' from 0)'
cp comfiles.out $GAS
rm comfiles.out
echo comfiles.out copied to $GAS and removed from current directory.

# Change directory to gas make all gas inputs 
cd $GAS

for i in `ls *.com`

do

	sed -i 's/MP2/HF/' $i                                                                          #ALTER HERE FOR CHANGE TO A DIFFERENT THEORY CURRENTLY WILL CHANGE FROM MP2 TO HF
	sed -i 's/6-31G\**/6-31G\*/' $i                                                                #ALTER HERE TO CHANGE FOR A DIFFERENT BASIS SET CURRENTLY WILL CHANGE FROM 6-31G** TO 6-31G*
	sed -i 's/SP density=mp2 nosymm Formcheck=all/opt freq integral(grid=ultrafine)/' $i           #ALTER TO SELECT DIFFERENT OPTIONS IN GAUSSIAN09
	sed -i 's/maxdisk.*//' $i
	sed -i 's/Maxdisk.*//' $i
	sed -i 's/MaxDisk.*//' $i
	sed -i 's/maxDisk.*//' $i
	sed -i 's/%mem=1gb/%mem=4gb/' $i

done


# Write the control lines for the batch job file. THIS MAY NEED EXTENSIVE EDITING TO REACH THE REQUIREMENTS FOR DIFFERENT MACHINES AND OPERATING SYSTEMS
echo job file name will be named jobs_gas

echo '#'!/bin/bash>jobs_gas
echo '#'SBATCH -J crys_to_gas >>jobs_gas
echo '#'SBATCH -N 1 >>jobs_gas
echo '#'SBATCH -n 12 >>jobs_gas
echo '#'SBATCH -t 48:00:00>>jobs_gas
echo '#'SBATCH -p exclusive>>jobs_gas
echo >> jobs_gas
echo source/opt/intel/composerxe/bin/compilervars.sh intel64 >>jobs_gas
echo source /opt/intel/impi/4.0.1/bin64/mpivars.sh >>jobs_gas
echo export I_MPI_FABRICS=shm:dapl >>jobs_gas
echo >>jobs_gas

# PLEASE EDIT THE ABOVE FOR YOUR MACHINE 

# Read in comfile names
while read line
do
	a=$(($a+1))
	echo new a is $a therefore reading for line number $a
	j=`sed -n $a'p' comfiles.out`
	echo $j 
	echo g09run $gas/$j >>jobs_gas
done < comfiles.out

cp jobs_gas $GAS
cd $home                                                                                                                                                                                                                                   


echo Done and finished all molcules now ready for submission of gas phase '#' M062X/6-31G* opt freq integral'(grid=ultrafine)' in $gas

exit
