############################################################################
#
# Simple script to extract coordinates (of molecule 1 in Angstroms) from 
#   a fort.21 file generated by NEIGHCRYS (part of the DMACRYS package)
#
# Usage:
#	 - python dmacrys_coord2gaussian.py (infile) (outfileid)
#
# Output:
#	 - (fileid).geom - file containing coordinates and NEIGHCRYS atom labels
#	 - (fileid).xyz  - xyz file
#
# Notes:
#	 - (infile) should be the fort.21 file produced by neighbours
#	 - (outfileid) is only used to name the output files.  It can be any string
#	 - it is intended that the .xyz file can be used to setup Gaussian DMA jobs.
#          Using e.g. gaussian_setup_xyz.py
#
# Originally developed by D.S.Palmer, Max Planck Institute for Mathematics in the Sciences/University of Strathclyde. Edited by J.L. McDonagh, University of St Andrews, for use with the W99 potential.
############################################################################

import sys

if len(sys.argv)!=3:
  print "\nERROR! Correct usage is 'python dmacrys_coord2gaussian.py (fileid)'"
  sys.exit("... where (fileid) is the name of the output file (without extension)\n")


#Read data
read="FALSE"
input=[]
for line in open(sys.argv[1],"r"):
  if line.find("x y z (AU)")!=-1:
    read="FALSE"
  if line.find("Atom positions in local axis system for molecule    1")!=-1:
    read="TRUE"
  if read=="TRUE":
    input.append(line)

#Tidy up
input.reverse()
input.pop()
input.pop()
input.pop()
input.pop()
input.reverse()
input.pop()

#Write output
outfile1=open(sys.argv[2]+".geom", "w")
outfile2=open(sys.argv[2]+".xyz", "w")

outfile2.write(str(len(input))+"\n")
outfile2.write(sys.argv[2]+"\n")
for line in input:
  #Write .geom file
  outfile1.write(line)

  #Write gaussian .com file
  tmp=line.split() 
  tmp2=tmp[1].split("_")[0]
  tmp3=tmp2+" "+tmp[2]+" "+tmp[3]+" "+tmp[4]+"\n"
  outfile2.write(tmp3)

outfile1.close()
outfile2.close()


