#######################################################################################################################
#
# Script to create Gaussian .com files for either (i) all .chk, or (ii) all .xyz, files in directory
# 
# Usage:
#	- python dmacrys_punchlabels.py (punchfile) (geomfile)
#
#
# Output:
#	- new.punch             ...     punch file containing DMACRYS labels
#
# Originally developed by D.S.Palmer, Max Planck Institute for Mathematics in the Sciences/University of Strathclyde. Edited by J.L. McDonagh, University of St Andrews, for use with the W99 potential.
#######################################################################################################################

import os, sys, shutil

################################################################
#
# Main Program
#
################################################################

#Check input
if len(sys.argv)!=3:
  print("ERROR! Correct syntax: 'python *py (punch) (geom)'")
  print("where ... (options) selects method (see code)")
  print("      ... (infiletype) must be either '.xyz' or '.chk'")
  sys.exit()

punch=sys.argv[1]
geom=sys.argv[2]

#Read dmacrys atom labels from .geom file
dmacryslabels=[]
for line in open(geom, "r"):
  if line.find("___")!=-1:
    tmp=line.split()
    dmacryslabels.append(tmp[1])
dmacryslabels.reverse()

#Edit punch file
output=open("new.punch", "w")
for line in open(punch, "r"):
  if line.find(" Rank ")!=-1:
    line2=dmacryslabels.pop()+line[10:]
    output.write(line2)
  else:
    output.write(line)
output.close()

print("FINISHED! Output written to new.punch")
