#################################
# Test data
#################################
testFilePath1 <- "./test_data/test_file.txt"
testMatrix1 <- matrix(c(1,2,3, 11,12,13), nrow = 2, ncol = 3, byrow = TRUE,
       dimnames = list(c("row1", "row2"), c("col1", "col2", "col3")))
testVector1 <- c(1, 2, 3)  
testVector2 <- c(2, 3, 4) 

##############################
# Test functions
##############################
  test.rmse <- function(){
    rmse1 <- rmse(testVector1, testVector1) # same values for predicted & observed: RMSE should be zero.
    checkEqualsNumeric(0, rmse1)
    
    rmse2 <- rmse(testVector2, testVector1)
    checkEqualsNumeric(round(1.0, digits = 4), rmse2)
  }

test.coefficientOfDetermination <- function(){
  r2_1 <- coefficientOfDetermination(testVector1, testVector1) # same values for predicted & observed: R2 should be zero.
  checkEqualsNumeric(1, r2_1)
  
  r2_2 <- coefficientOfDetermination(testVector2, testVector1)
  message("r2_2: ", r2_2)
  checkEqualsNumeric(round(-0.5, digits = 4),  r2_2)
}

test.pearsonR2 <- function(){
  r2_1 <- pearsonRSquared(testVector1, testVector1) # same values for predicted & observed: R2 should be zero.
  message("r2_1: ", r2_1)
  checkEqualsNumeric(round(1.0, digits = 4), r2_1)
  
  r2_2 <- pearsonRSquared(testVector2, testVector1)
  message("r2_2: ", r2_2)
  checkEqualsNumeric(round(1.0, digits = 4),  r2_2)
}

  test.writeErrorMetricsTable <- function(){
  # create test table 
  data <- testMatrix1
  filePath <- testFilePath1
  
  # write test table to test file
  writeErrorMetricsTable(data, 5, "description", filePath) 
  
  # check what's written
  lines <- readLines(filePath)
  print(lines[1])
  print(lines[6])
  
  checkEquals(6, length(lines))
  checkEquals("5,description,col1,row1,1", lines[1])
  checkEquals("5,description,col3,row2,13", lines[6])
  
  # erase file
  erase(filePath)
  
  # checkEquals(6, factorial(3))
  # checkEqualsNumeric(6, factorial(3))
  # checkIdentical(6, factorial(3))
  # checkTrue(2 + 2 == 4, 'Arithmetic works')
  # checkException(log('a'), 'Unable to take the log() of a string')
}

erase <-function(filePath){
  file.remove(filePath)
  checkTrue(!file.exists(filePath))
  
}